==> eam-wshub-proxyclient-11.7-2-sources.jar: net/datastream/schemas/mp_functions/mp0118_getgridheaderdata_001_result/ObjectFactory.java <==

package net.datastream.schemas.mp_functions.mp0118_getgridheaderdata_001_result;

import javax.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_functions.mp0118_getgridheaderdata_001_result package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_functions.mp0118_getgridheaderdata_001_result
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link TOOLBAR }
     * 
     */
    public TOOLBAR createTOOLBAR() {
        return new TOOLBAR();
    }

    /**
     * Create an instance of {@link METADATA }
     * 
     */
    public METADATA createMETADATA() {
        return new METADATA();
    }

    /**
     * Create an instance of {@link DATA }
     * 
     */
    public DATA createDATA() {
        return new DATA();
    }

    /**
     * Create an instance of {@link DATA.ROW }
     * 
     */
    public DATA.ROW createDATAROW() {
        return new DATA.ROW();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELDVALUES }
     * 
     */
    public TOOLBAR.FIELDVALUES createTOOLBARFIELDVALUES() {
        return new TOOLBAR.FIELDVALUES();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELDVALUES.ROW }
     * 
     */
    public TOOLBAR.FIELDVALUES.ROW createTOOLBARFIELDVALUESROW() {
        return new TOOLBAR.FIELDVALUES.ROW();
    }

    /**
     * Create an instance of {@link TOOLBAR.DATASPYDETAIL }
     * 
     */
    public TOOLBAR.DATASPYDETAIL createTOOLBARDATASPYDETAIL() {
        return new TOOLBAR.DATASPYDETAIL();
    }

    /**
     * Create an instance of {@link TOOLBAR.DATASPYDETAIL.SORTABLE }
     * 
     */
    public TOOLBAR.DATASPYDETAIL.SORTABLE createTOOLBARDATASPYDETAILSORTABLE() {
        return new TOOLBAR.DATASPYDETAIL.SORTABLE();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELD }
     * 
     */
    public TOOLBAR.FIELD createTOOLBARFIELD() {
        return new TOOLBAR.FIELD();
    }

    /**
     * Create an instance of {@link MP0118_GetGridHeaderData_001_Result }
     * 
     */
    public MP0118_GetGridHeaderData_001_Result createMP0118_GetGridHeaderData_001_Result() {
        return new MP0118_GetGridHeaderData_001_Result();
    }

    /**
     * Create an instance of {@link GRIDRESULT }
     * 
     */
    public GRIDRESULT createGRIDRESULT() {
        return new GRIDRESULT();
    }

    /**
     * Create an instance of {@link DATASPY }
     * 
     */
    public DATASPY createDATASPY() {
        return new DATASPY();
    }

    /**
     * Create an instance of {@link GRID }
     * 
     */
    public GRID createGRID() {
        return new GRID();
    }

    /**
     * Create an instance of {@link METADATA.HASCREATEAUTH }
     * 
     */
    public METADATA.HASCREATEAUTH createMETADATAHASCREATEAUTH() {
        return new METADATA.HASCREATEAUTH();
    }

    /**
     * Create an instance of {@link DATA.R }
     * 
     */
    public DATA.R createDATAR() {
        return new DATA.R();
    }

    /**
     * Create an instance of {@link FIELDS }
     * 
     */
    public FIELDS createFIELDS() {
        return new FIELDS();
    }

    /**
     * Create an instance of {@link net.datastream.schemas.mp_functions.mp0118_getgridheaderdata_001_result.FIELD }
     * 
     */
    public net.datastream.schemas.mp_functions.mp0118_getgridheaderdata_001_result.FIELD createFIELD() {
        return new net.datastream.schemas.mp_functions.mp0118_getgridheaderdata_001_result.FIELD();
    }

    /**
     * Create an instance of {@link Optn }
     * 
     */
    public Optn createOptn() {
        return new Optn();
    }

    /**
     * Create an instance of {@link Option }
     * 
     */
    public Option createOption() {
        return new Option();
    }

    /**
     * Create an instance of {@link Filterfields_Type }
     * 
     */
    public Filterfields_Type createFilterfields_Type() {
        return new Filterfields_Type();
    }

    /**
     * Create an instance of {@link DATA.ROW.D }
     * 
     */
    public DATA.ROW.D createDATAROWD() {
        return new DATA.ROW.D();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELDVALUES.ROW.Dataspylist_Options }
     * 
     */
    public TOOLBAR.FIELDVALUES.ROW.Dataspylist_Options createTOOLBARFIELDVALUESROWDataspylist_Options() {
        return new TOOLBAR.FIELDVALUES.ROW.Dataspylist_Options();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELDVALUES.ROW.Filterfields_Options }
     * 
     */
    public TOOLBAR.FIELDVALUES.ROW.Filterfields_Options createTOOLBARFIELDVALUESROWFilterfields_Options() {
        return new TOOLBAR.FIELDVALUES.ROW.Filterfields_Options();
    }

    /**
     * Create an instance of {@link TOOLBAR.DATASPYDETAIL.SORTABLEFLDS }
     * 
     */
    public TOOLBAR.DATASPYDETAIL.SORTABLEFLDS createTOOLBARDATASPYDETAILSORTABLEFLDS() {
        return new TOOLBAR.DATASPYDETAIL.SORTABLEFLDS();
    }

    /**
     * Create an instance of {@link TOOLBAR.DATASPYDETAIL.DEFAULT }
     * 
     */
    public TOOLBAR.DATASPYDETAIL.DEFAULT createTOOLBARDATASPYDETAILDEFAULT() {
        return new TOOLBAR.DATASPYDETAIL.DEFAULT();
    }

    /**
     * Create an instance of {@link TOOLBAR.DATASPYDETAIL.DISPLAYABLEFLDS }
     * 
     */
    public TOOLBAR.DATASPYDETAIL.DISPLAYABLEFLDS createTOOLBARDATASPYDETAILDISPLAYABLEFLDS() {
        return new TOOLBAR.DATASPYDETAIL.DISPLAYABLEFLDS();
    }

    /**
     * Create an instance of {@link TOOLBAR.DATASPYDETAIL.FILTERABLEFLDS }
     * 
     */
    public TOOLBAR.DATASPYDETAIL.FILTERABLEFLDS createTOOLBARDATASPYDETAILFILTERABLEFLDS() {
        return new TOOLBAR.DATASPYDETAIL.FILTERABLEFLDS();
    }

    /**
     * Create an instance of {@link TOOLBAR.DATASPYDETAIL.DATASPYHINTS }
     * 
     */
    public TOOLBAR.DATASPYDETAIL.DATASPYHINTS createTOOLBARDATASPYDETAILDATASPYHINTS() {
        return new TOOLBAR.DATASPYDETAIL.DATASPYHINTS();
    }

    /**
     * Create an instance of {@link TOOLBAR.DATASPYDETAIL.GRIDHINTS }
     * 
     */
    public TOOLBAR.DATASPYDETAIL.GRIDHINTS createTOOLBARDATASPYDETAILGRIDHINTS() {
        return new TOOLBAR.DATASPYDETAIL.GRIDHINTS();
    }

    /**
     * Create an instance of {@link TOOLBAR.DATASPYDETAIL.SECURITYDSP }
     * 
     */
    public TOOLBAR.DATASPYDETAIL.SECURITYDSP createTOOLBARDATASPYDETAILSECURITYDSP() {
        return new TOOLBAR.DATASPYDETAIL.SECURITYDSP();
    }

    /**
     * Create an instance of {@link TOOLBAR.DATASPYDETAIL.SORTABLE.SORT_ELEMENT }
     * 
     */
    public TOOLBAR.DATASPYDETAIL.SORTABLE.SORT_ELEMENT createTOOLBARDATASPYDETAILSORTABLESORT_ELEMENT() {
        return new TOOLBAR.DATASPYDETAIL.SORTABLE.SORT_ELEMENT();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELD.OPTION }
     * 
     */
    public TOOLBAR.FIELD.OPTION createTOOLBARFIELDOPTION() {
        return new TOOLBAR.FIELD.OPTION();
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_functions/mp0118_getgridheaderdata_001_result/ObjectFactory.java <==

package net.datastream.schemas.mp_functions.mp0118_getgridheaderdata_001_result;

import jakarta.xml.bind.annotation.XmlRegistry;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the net.datastream.schemas.mp_functions.mp0118_getgridheaderdata_001_result package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {


    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: net.datastream.schemas.mp_functions.mp0118_getgridheaderdata_001_result
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link TOOLBAR }
     * 
     * @return
     *     the new instance of {@link TOOLBAR }
     */
    public TOOLBAR createTOOLBAR() {
        return new TOOLBAR();
    }

    /**
     * Create an instance of {@link METADATA }
     * 
     * @return
     *     the new instance of {@link METADATA }
     */
    public METADATA createMETADATA() {
        return new METADATA();
    }

    /**
     * Create an instance of {@link DATA }
     * 
     * @return
     *     the new instance of {@link DATA }
     */
    public DATA createDATA() {
        return new DATA();
    }

    /**
     * Create an instance of {@link DATA.ROW }
     * 
     * @return
     *     the new instance of {@link DATA.ROW }
     */
    public DATA.ROW createDATAROW() {
        return new DATA.ROW();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELDVALUES }
     * 
     * @return
     *     the new instance of {@link TOOLBAR.FIELDVALUES }
     */
    public TOOLBAR.FIELDVALUES createTOOLBARFIELDVALUES() {
        return new TOOLBAR.FIELDVALUES();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELDVALUES.ROW }
     * 
     * @return
     *     the new instance of {@link TOOLBAR.FIELDVALUES.ROW }
     */
    public TOOLBAR.FIELDVALUES.ROW createTOOLBARFIELDVALUESROW() {
        return new TOOLBAR.FIELDVALUES.ROW();
    }

    /**
     * Create an instance of {@link TOOLBAR.DATASPYDETAIL }
     * 
     * @return
     *     the new instance of {@link TOOLBAR.DATASPYDETAIL }
     */
    public TOOLBAR.DATASPYDETAIL createTOOLBARDATASPYDETAIL() {
        return new TOOLBAR.DATASPYDETAIL();
    }

    /**
     * Create an instance of {@link TOOLBAR.DATASPYDETAIL.SORTABLE }
     * 
     * @return
     *     the new instance of {@link TOOLBAR.DATASPYDETAIL.SORTABLE }
     */
    public TOOLBAR.DATASPYDETAIL.SORTABLE createTOOLBARDATASPYDETAILSORTABLE() {
        return new TOOLBAR.DATASPYDETAIL.SORTABLE();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELD }
     * 
     * @return
     *     the new instance of {@link TOOLBAR.FIELD }
     */
    public TOOLBAR.FIELD createTOOLBARFIELD() {
        return new TOOLBAR.FIELD();
    }

    /**
     * Create an instance of {@link MP0118_GetGridHeaderData_001_Result }
     * 
     * @return
     *     the new instance of {@link MP0118_GetGridHeaderData_001_Result }
     */
    public MP0118_GetGridHeaderData_001_Result createMP0118_GetGridHeaderData_001_Result() {
        return new MP0118_GetGridHeaderData_001_Result();
    }

    /**
     * Create an instance of {@link GRIDRESULT }
     * 
     * @return
     *     the new instance of {@link GRIDRESULT }
     */
    public GRIDRESULT createGRIDRESULT() {
        return new GRIDRESULT();
    }

    /**
     * Create an instance of {@link DATASPY }
     * 
     * @return
     *     the new instance of {@link DATASPY }
     */
    public DATASPY createDATASPY() {
        return new DATASPY();
    }

    /**
     * Create an instance of {@link GRID }
     * 
     * @return
     *     the new instance of {@link GRID }
     */
    public GRID createGRID() {
        return new GRID();
    }

    /**
     * Create an instance of {@link METADATA.HASCREATEAUTH }
     * 
     * @return
     *     the new instance of {@link METADATA.HASCREATEAUTH }
     */
    public METADATA.HASCREATEAUTH createMETADATAHASCREATEAUTH() {
        return new METADATA.HASCREATEAUTH();
    }

    /**
     * Create an instance of {@link DATA.R }
     * 
     * @return
     *     the new instance of {@link DATA.R }
     */
    public DATA.R createDATAR() {
        return new DATA.R();
    }

    /**
     * Create an instance of {@link FIELDS }
     * 
     * @return
     *     the new instance of {@link FIELDS }
     */
    public FIELDS createFIELDS() {
        return new FIELDS();
    }

    /**
     * Create an instance of {@link net.datastream.schemas.mp_functions.mp0118_getgridheaderdata_001_result.FIELD }
     * 
     * @return
     *     the new instance of {@link net.datastream.schemas.mp_functions.mp0118_getgridheaderdata_001_result.FIELD }
     */
    public net.datastream.schemas.mp_functions.mp0118_getgridheaderdata_001_result.FIELD createFIELD() {
        return new net.datastream.schemas.mp_functions.mp0118_getgridheaderdata_001_result.FIELD();
    }

    /**
     * Create an instance of {@link Optn }
     * 
     * @return
     *     the new instance of {@link Optn }
     */
    public Optn createOptn() {
        return new Optn();
    }

    /**
     * Create an instance of {@link Option }
     * 
     * @return
     *     the new instance of {@link Option }
     */
    public Option createOption() {
        return new Option();
    }

    /**
     * Create an instance of {@link Filterfields_Type }
     * 
     * @return
     *     the new instance of {@link Filterfields_Type }
     */
    public Filterfields_Type createFilterfields_Type() {
        return new Filterfields_Type();
    }

    /**
     * Create an instance of {@link DATA.ROW.D }
     * 
     * @return
     *     the new instance of {@link DATA.ROW.D }
     */
    public DATA.ROW.D createDATAROWD() {
        return new DATA.ROW.D();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELDVALUES.ROW.Dataspylist_Options }
     * 
     * @return
     *     the new instance of {@link TOOLBAR.FIELDVALUES.ROW.Dataspylist_Options }
     */
    public TOOLBAR.FIELDVALUES.ROW.Dataspylist_Options createTOOLBARFIELDVALUESROWDataspylist_Options() {
        return new TOOLBAR.FIELDVALUES.ROW.Dataspylist_Options();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELDVALUES.ROW.Filterfields_Options }
     * 
     * @return
     *     the new instance of {@link TOOLBAR.FIELDVALUES.ROW.Filterfields_Options }
     */
    public TOOLBAR.FIELDVALUES.ROW.Filterfields_Options createTOOLBARFIELDVALUESROWFilterfields_Options() {
        return new TOOLBAR.FIELDVALUES.ROW.Filterfields_Options();
    }

    /**
     * Create an instance of {@link TOOLBAR.DATASPYDETAIL.SORTABLEFLDS }
     * 
     * @return
     *     the new instance of {@link TOOLBAR.DATASPYDETAIL.SORTABLEFLDS }
     */
    public TOOLBAR.DATASPYDETAIL.SORTABLEFLDS createTOOLBARDATASPYDETAILSORTABLEFLDS() {
        return new TOOLBAR.DATASPYDETAIL.SORTABLEFLDS();
    }

    /**
     * Create an instance of {@link TOOLBAR.DATASPYDETAIL.DEFAULT }
     * 
     * @return
     *     the new instance of {@link TOOLBAR.DATASPYDETAIL.DEFAULT }
     */
    public TOOLBAR.DATASPYDETAIL.DEFAULT createTOOLBARDATASPYDETAILDEFAULT() {
        return new TOOLBAR.DATASPYDETAIL.DEFAULT();
    }

    /**
     * Create an instance of {@link TOOLBAR.DATASPYDETAIL.DISPLAYABLEFLDS }
     * 
     * @return
     *     the new instance of {@link TOOLBAR.DATASPYDETAIL.DISPLAYABLEFLDS }
     */
    public TOOLBAR.DATASPYDETAIL.DISPLAYABLEFLDS createTOOLBARDATASPYDETAILDISPLAYABLEFLDS() {
        return new TOOLBAR.DATASPYDETAIL.DISPLAYABLEFLDS();
    }

    /**
     * Create an instance of {@link TOOLBAR.DATASPYDETAIL.FILTERABLEFLDS }
     * 
     * @return
     *     the new instance of {@link TOOLBAR.DATASPYDETAIL.FILTERABLEFLDS }
     */
    public TOOLBAR.DATASPYDETAIL.FILTERABLEFLDS createTOOLBARDATASPYDETAILFILTERABLEFLDS() {
        return new TOOLBAR.DATASPYDETAIL.FILTERABLEFLDS();
    }

    /**
     * Create an instance of {@link TOOLBAR.DATASPYDETAIL.DATASPYHINTS }
     * 
     * @return
     *     the new instance of {@link TOOLBAR.DATASPYDETAIL.DATASPYHINTS }
     */
    public TOOLBAR.DATASPYDETAIL.DATASPYHINTS createTOOLBARDATASPYDETAILDATASPYHINTS() {
        return new TOOLBAR.DATASPYDETAIL.DATASPYHINTS();
    }

    /**
     * Create an instance of {@link TOOLBAR.DATASPYDETAIL.GRIDHINTS }
     * 
     * @return
     *     the new instance of {@link TOOLBAR.DATASPYDETAIL.GRIDHINTS }
     */
    public TOOLBAR.DATASPYDETAIL.GRIDHINTS createTOOLBARDATASPYDETAILGRIDHINTS() {
        return new TOOLBAR.DATASPYDETAIL.GRIDHINTS();
    }

    /**
     * Create an instance of {@link TOOLBAR.DATASPYDETAIL.SECURITYDSP }
     * 
     * @return
     *     the new instance of {@link TOOLBAR.DATASPYDETAIL.SECURITYDSP }
     */
    public TOOLBAR.DATASPYDETAIL.SECURITYDSP createTOOLBARDATASPYDETAILSECURITYDSP() {
        return new TOOLBAR.DATASPYDETAIL.SECURITYDSP();
    }

    /**
     * Create an instance of {@link TOOLBAR.DATASPYDETAIL.SORTABLE.SORT_ELEMENT }
     * 
     * @return
     *     the new instance of {@link TOOLBAR.DATASPYDETAIL.SORTABLE.SORT_ELEMENT }
     */
    public TOOLBAR.DATASPYDETAIL.SORTABLE.SORT_ELEMENT createTOOLBARDATASPYDETAILSORTABLESORT_ELEMENT() {
        return new TOOLBAR.DATASPYDETAIL.SORTABLE.SORT_ELEMENT();
    }

    /**
     * Create an instance of {@link TOOLBAR.FIELD.OPTION }
     * 
     * @return
     *     the new instance of {@link TOOLBAR.FIELD.OPTION }
     */
    public TOOLBAR.FIELD.OPTION createTOOLBARFIELDOPTION() {
        return new TOOLBAR.FIELD.OPTION();
    }

}
